@@ -16,6 +16,8 @@
 /* FIXME Symbol needed by panel-util.c - sucky */
 #include "applet.h"
 GSList *panel_applet_list_applets (void) { return NULL; }
+#include "panel-config-global.h"
+gboolean panel_global_config_get_tooltips_enabled (void) { return FALSE; }
 
 static int dialogs = 0;
 static gboolean create_new = FALSE;
@@ -126,8 +128,8 @@ main (int argc, char * argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	context = g_option_context_new (_("- Edit .desktop files"));
-
+	context = g_option_context_new (N_("- Edit .desktop files"));
+	g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
 	program = gnome_program_init ("gnome-desktop-item-edit", VERSION,
