@@ -119,12 +119,21 @@ void    panel_util_key_file_set_locale_string (GKeyFile    *keyfile,
 	g_key_file_remove_key (key_file, "Desktop Entry", key, NULL)
 void panel_util_key_file_remove_locale_key (GKeyFile    *keyfile,
 					    const gchar *key);
+void panel_util_key_file_remove_all_locale_key (GKeyFile    *keyfile,
+						const gchar *key);
 void panel_util_key_file_ensure_C_key (GKeyFile   *keyfile,
 				       const char *key);
 
 char *guess_icon_from_exec (GtkIconTheme *icon_theme,
 			    GKeyFile     *key_file);
 
+const char *panel_util_get_vfs_method_display_name (const char *method);
+char *panel_util_get_label_for_uri (const char *text_uri);
+char *panel_util_get_icon_for_uri (const char *text_uri);
+
+void panel_util_set_tooltip_text (GtkWidget  *widget,
+				  const char *text);
+
 G_END_DECLS
 
 #endif /* PANEL_UTIL_H */
